/*
 * This file is part of the Generic Data Structures Library (GDSL).
 * Copyright (C) 1998-2017 Nicolas Darnis <ndarnis@free.fr>.
 *
 * GDSL is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GDSL is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GDSL.  If not, see <http://www.gnu.org/licenses/>. 
 *
 * $RCSfile: _strings.c,v $
 * $Revision: 1.13 $
 * $Date: 2015/02/17 12:33:16 $
 */


#include <stdlib.h>
#include <string.h>


#include "gdsl_types.h"


#include "_strings.h"


extern gdsl_element_t
alloc_string (void* string)
{
    return (gdsl_element_t) strdup ((char*) string);
}

extern void
free_string (gdsl_element_t e)
{
    free (e);
}

extern gdsl_element_t
copy_string (gdsl_element_t e)
{
    return (gdsl_element_t) strdup ((char*) e);
}

extern void
print_string (gdsl_element_t e, FILE* file, gdsl_location_t location, void* d)
{
    char loc [256] = "";

    if (location & GDSL_LOCATION_ROOT)
	{
	    strcat (loc, "ROOT ");
	}

    if (location & GDSL_LOCATION_LEAF)
	{
	    strcat (loc, "LEAF ");
	}

    if (d == NULL)
	{
	    fprintf (file, "%s%s", (char*) e, loc);
	}
    else
	{
	    fprintf (file, "%s%s%s", (char*) e, loc, (char*) d);
	}
}

extern long int
compare_strings (gdsl_element_t s1, void* s2)
{
    return strcmp ((char*) s1, (char*) s2);
}


/** EMACS **
 * Local variables:
 * mode: c
 * c-basic-offset: 4
 * End:
 */
